@@ -51,8 +51,8 @@ progbar=TRUE,
 #
 if(!missing(data)) # get vectors from data.frame
   {
-  dates <- data[ , deparse(substitute(dates))]
-  values<- data[ , deparse(substitute(values))]
+  dates  <- getColumn(substitute(dates ), data)
+  values <- getColumn(substitute(values), data)
   }
 #
 steps <- max(steps) # in case the user inputs a vector
